"use client"

import type { Locale } from "@repo/i18n/config"
import { Button } from "@repo/ui/design/Button"
import { Link } from "@repo/ui/design/Link"
import { Typography } from "@repo/ui/design/Typography"
import { useLocale } from "next-intl"
import { useState } from "react"
import {
  fromLocaleToWikipediaLocale,
  getWikipediaLink,
  getWikipediaPageInternalLinks,
} from "./wikipedia-api"

export const WikipediaClient: React.FC = () => {
  const [isLoading, setIsLoading] = useState(false)

  const localeCurrent = useLocale() as Locale
  const localeWikipedia = fromLocaleToWikipediaLocale(localeCurrent)

  const handleClick: React.MouseEventHandler<HTMLButtonElement> = async () => {
    setIsLoading(true)
    const fromArticleInput = "Linux"
    const toArticleInput = "Node.js"
    console.log({
      fromArticleInput,
      toArticleInput,
    })
    const [fromArticleWikipediaLinks, toArticleWikipediaLinks] =
      await Promise.all([
        getWikipediaPageInternalLinks({
          title: fromArticleInput,
          locale: localeWikipedia,
        }),
        getWikipediaPageInternalLinks({
          title: toArticleInput,
          locale: localeWikipedia,
        }),
      ])
    console.log({
      fromArticleWikipediaLinks,
      toArticleWikipediaLinks,
    })
    setIsLoading(false)
  }

  return (
    <section className="my-6 flex items-center justify-center space-x-6">
      <Button onClick={handleClick} isLoading={isLoading} className="w-36">
        Wikipedia
      </Button>
      <Typography variant="text1" as="p">
        <span>Using: </span>
        <Link href={getWikipediaLink(localeWikipedia)} target="_blank">
          {getWikipediaLink(localeWikipedia).replace("https://", "")}
        </Link>
      </Typography>
    </section>
  )
}
